summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2002-03-08 01:31:27 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2009-04-06 16:06:49 -0500
commit377657d1d63d62aca585f1b10b5822767008a214 (patch)
tree7a1af307d2ed7deed51ccd3b30424b93625f9e2a /png.h
parentc1bfe686ce0bafc1572ed2978b3df7671d40d0b8 (diff)
downloadlibpng-377657d1d63d62aca585f1b10b5822767008a214.tar.gz
Imported from libpng-1.2.2beta4.tarv1.2.2beta4
Diffstat (limited to 'png.h')
-rw-r--r--png.h32
1 files changed, 19 insertions, 13 deletions
diff --git a/png.h b/png.h
index 4dc3f917d..3057fbd0a 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.2.2beta3 - March 7, 2002
* Copyright (c) 1998-2002 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -9,7 +9,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.2.2beta3 - March 7, 2002: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -81,7 +81,7 @@
* 1.2.1beta1-4 3 10201 3.1.2.1beta1-4
* 1.2.1rc1-2 3 10201 3.1.2.1rc1-2
* 1.2.1 3 10201 3.1.2.1
- * 1.2.2beta1-3 12 10202 12.so.0.1.2.2beta1-3
+ * 1.2.2beta1-4 12 10202 12.so.0.1.2.2beta1-4
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -111,7 +111,7 @@
* If you modify libpng you may insert additional notices immediately following
* this sentence.
*
* libpng versions 1.0.7, July 1, 2000, through 1.2.2beta3, March 7, 2002, are
* Copyright (c) 2000, 2002 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.0.6
* with the following individuals added to the list of Contributing Authors
@@ -216,13 +216,13 @@
* Y2K compliance in libpng:
* =========================
*
- * March 7, 2002
+ * March 8, 2002
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.2.2beta3 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -278,7 +278,7 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.2.2beta3"
+#define PNG_LIBPNG_VER_STRING "1.2.2beta4"
#define PNG_LIBPNG_VER_SONUM 0
#define PNG_LIBPNG_VER_DLLNUM %DLLNUM%
@@ -290,7 +290,7 @@
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero: */
-#define PNG_LIBPNG_VER_BUILD 3
+#define PNG_LIBPNG_VER_BUILD 4
#define PNG_LIBPNG_BUILD_ALPHA 1
#define PNG_LIBPNG_BUILD_BETA 2
@@ -1216,7 +1216,11 @@ struct png_struct_def
defined(PNG_READ_EMPTY_PLTE_SUPPORTED) || \
defined(PNG_WRITE_EMPTY_PLTE_SUPPORTED)
/* changed from png_byte to png_uint_32 at version 1.2.0 */
+#ifdef PNG_1_0_X
+ png_byte mng_features_permitted;
+#else
png_uint_32 mng_features_permitted;
+#endif /* PNG_1_0_X */
#endif
/* New member added in libpng-1.0.7 */
@@ -1229,13 +1233,13 @@ struct png_struct_def
png_byte filter_type;
#endif
-#if defined(PNG_DEBUG) && defined(PNG_USE_PNGGCCRD)
+#if defined(PNG_1_0_X) || (defined(PNG_DEBUG) && defined(PNG_USE_PNGGCCRD))
/* New member added in libpng-1.0.10, ifdef'ed out in 1.2.0 */
png_uint_32 row_buf_size;
#endif
/* New members added in libpng-1.2.0 */
-#if defined(PNG_ASSEMBLER_CODE_SUPPORTED)
+#if !defined(PNG_1_0_X) && defined(PNG_ASSEMBLER_CODE_SUPPORTED)
png_byte mmx_bitdepth_threshold;
png_uint_32 mmx_rowbytes_threshold;
png_uint_32 asm_flags;
@@ -1254,9 +1258,9 @@ struct png_struct_def
/* This prevents a compiler error in png_get_copyright() in png.c if png.c
- and png.h are both at version 1.2.2beta3
+ and png.h are both at version 1.2.2beta4
*/
-typedef png_structp version_1_2_2beta3;
+typedef png_structp version_1_2_2beta4;
typedef png_struct FAR * FAR * png_structpp;
@@ -2337,6 +2341,7 @@ extern PNG_EXPORT(png_uint_32,png_permit_mng_features) PNGARG((png_structp
#define PNG_SELECT_WRITE 2
+#if !defined(PNG_1_0_X)
/* pngget.c */
extern PNG_EXPORT(png_uint_32,png_get_mmx_flagmask)
PNGARG((int flag_select, int *compilerID));
@@ -2366,6 +2371,7 @@ extern PNG_EXPORT(void,png_set_mmx_thresholds)
PNGARG((png_structp png_ptr, png_byte mmx_bitdepth_threshold,
png_uint_32 mmx_rowbytes_threshold));
+#endif /* PNG_1_0_X */
#endif /* PNG_ASSEMBLER_CODE_SUPPORTED */
/* png.c, pnggccrd.c, or pngvcrd.c */
@@ -2381,7 +2387,7 @@ extern PNG_EXPORT(void,png_set_strip_error_numbers) PNGARG((png_structp
/* Maintainer: Put new public prototypes here ^, in libpng.3, and project defs */
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.2.2beta3 - March 7, 2002 (header)\n"
+ " libpng version 1.2.2beta4 - March 8, 2002 (header)\n"
#ifdef PNG_READ_COMPOSITE_NODIV_SUPPORTED
/* With these routines we avoid an integer divide, which will be slower on
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.2.2beta3 - March 7, 2002
+ * libpng version 1.2.2beta4 - March 8, 2002
* Copyright (c) 1998-2002 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -9,7 +9,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.2.2beta3 - March 7, 2002: Glenn
+ * libpng versions 0.97, January 1998, through 1.2.2beta4 - March 8, 2002: Glenn
* See also "Contributing Authors", below.
*
@@ -111,7 +111,7 @@
* this sentence.
*
- * libpng versions 1.0.7, July 1, 2000, through 1.2.2beta3, March 7, 2002, are
+ * libpng versions 1.0.7, July 1, 2000, through 1.2.2beta4, March 8, 2002, are
* Copyright (c) 2000, 2002 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.0.6
@@ -216,13 +216,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.2.2beta3 are Y2K compliant. It is my belief that earlier
+ * upward through 1.2.2beta4 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*